@@ -555,7 +555,7 @@ def getFileList(path,  filter):
     while(i>=0):
 #        print i
         if(string.find(arr[i],  "%")!=-1 or string.find(arr[i],  ",")!=-1):
-            print "Remove file",  arr[i],  "from list, name contaions illegal characters"
+            print "Remove file",  arr[i],  "from list, name contains illegal characters"
             arr.pop(i)
         i=i-1
     
